import { USER_SERVICE } from './../../providers/service.providers';
import { Component, OnInit, Inject } from '@angular/core';
import { UserService } from '../../services/user.service';
import { MyRegistration } from '../../models/MyRegistration';
import { WaitlistItem } from '../../models/WaitlistItem';
import { TranslationKeys } from 'src/app/constants/TranslationKeys';
import { LocalizableError } from 'src/app/models/LocalizableError';

@Component({
  selector: 'app-myregistrations',
  templateUrl: './myregistrations.component.html',
  styleUrls: ['./myregistrations.component.css']
})
export class MyRegistrationsComponent implements OnInit {
  public cntActiveDataRetrievals = 0;
  public error: Error;

  registrations: MyRegistration[];
  waitlistItems: WaitlistItem[];

  constructor(@Inject(USER_SERVICE) private userService: UserService) { }

  ngOnInit() {
    this.loadRegistrationsForUser();
    this.loadWaitlistItemsForUser();
  }

  private loadRegistrationsForUser(): void {
    this.cntActiveDataRetrievals += 1;

    this.userService.getRegistrationsForUser().subscribe(registrations => {
      this.registrations = registrations;
      this.cntActiveDataRetrievals -= 1;
    }, (error: LocalizableError) => this.handleErrorResponse(error));
  }

  private loadWaitlistItemsForUser(): void {
    this.cntActiveDataRetrievals += 1;
    this.userService.getWaitlistItemsForUser().subscribe(waitlistItems => {
        this.waitlistItems = waitlistItems;
        this.cntActiveDataRetrievals -= 1;
    }, (error: LocalizableError) => this.handleErrorResponse(error)
    );
  }

  public cancelRegistration(registrationId: string): void {
    this.cntActiveDataRetrievals += 1;
    this.userService.cancelRegistration(registrationId).subscribe(isRegistrationCanceled => {
      if (isRegistrationCanceled) {
        this.loadRegistrationsForUser();
        this.loadWaitlistItemsForUser();
        this.error = null;
      } else {
        this.error = new LocalizableError('An error occurred while cancelling the registration.', TranslationKeys.CancelRegistrationError);
      }
      this.cntActiveDataRetrievals -= 1;
    }, (error: LocalizableError) => this.handleErrorResponse(error)
    );
  }

  private handleErrorResponse(error: LocalizableError) {
    this.cntActiveDataRetrievals -= 1;
    this.error = error;
  }
}
